(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     62061,       1823]*)
(*NotebookOutlinePosition[     69405,       2033]*)
(*  CellTagsIndexPosition[     69242,       2024]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData["\[FilledSmallSquare]  SeriesSolve"], "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  ShowCellTags->False,
  CellTags->"Introduction"],

Cell[TextData[{
  "This package finds Maclaurin series expansions of the roots of an \
algebraic or transcendental equation, or system of equations. The function",
  StyleBox[" SeriesSolve", "MR"],
  " is analogous to the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Solve", "MR"],
  ", except that the results of the solution are expressed in terms of \
series. (The format of the resulting series solution is similar to that \
generated by the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Series", "MR"],
  ".) \n\nThe equations that are to be solved using ",
  StyleBox["SeriesSolve", "MR"],
  " must contain a small parameter in terms of which the solution series are \
expressed. For the method to work, it is necessary that the equation, or \
system of equations, that result when the small parameter is set to zero be \
capable of being solved by the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Solve", "MR"],
  " function. However, the original equation, or system of equations, need \
not be capable of being solved exactly in order for ",
  StyleBox["SeriesSolve", "MR"],
  " to find the series expansions of the root(s). (It is only necessary that \
the root of interest actually ",
  StyleBox["is",
    FontSlant->"Italic"],
  " expressible in a Maclaurin series.) In fact, the original equations can \
be transcendental. Also, ",
  StyleBox["SeriesSolve", "MR"],
  " can give series expansions of the roots in other cases for which no exact \
analytical root is available, such as in the general sixth-degree polynomial. \
The equation(s) obtained by setting the small parameter to zero in the \
original equation(s) is (are) called the \"zeroth order\" equations. The \
number of roots in the zeroth order equations determines the number of \
Maclaurin series solutions that are available, and the zeroth-order term in \
each of the series is given by one of the roots of the zeroth-order \
equation(s). \n \n\n\n "
}], "Text",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useage", "Section",
  CellTags->"Useage"],

Cell["Usesage of SeriesSolve", "Caption",
  CellTags->"Useage"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SeriesSolve",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["equation",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["variable",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[\(small\ parameter\),
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  CellTags->"Useage"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", GridBox[{
            {" ", 
              RowBox[{
                RowBox[{
                  StyleBox["Solve",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox["equation",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox[\((may\ also\ be\ a\ list\ of\ equations)\),
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["for",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["variable",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox[\((may\ also\ be\ a\ list\ of\ variables)\),
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["in",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["terms",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["of",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["a",
                    SingleLetterItalics->False], 
                  StyleBox["  ",
                    SingleLetterItalics->False], 
                  StyleBox["Maclaurin",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["series",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["expressed",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["in",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["terms",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["of",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["the",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox["small",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox["parameter",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"], 
                  StyleBox["contained",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox["in",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox["the",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox[
                    RowBox[{
                      StyleBox["equation",
                        SingleLetterItalics->False,
                        FontSlant->"Italic"], 
                      StyleBox[".",
                        SingleLetterItalics->False,
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        SingleLetterItalics->False,
                        FontSlant->"Italic"], 
                      StyleBox["By",
                        SingleLetterItalics->False,
                        FontSlant->"Plain"]}],
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"], 
                  StyleBox["default",
                    SingleLetterItalics->False,
                    FontSlant->"Plain"]}], 
                StyleBox[",",
                  SingleLetterItalics->False,
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  SingleLetterItalics->False,
                  FontSlant->"Plain"], 
                
                StyleBox[
                  \(the\ series\ are\ truncated\ at\ second\ \(order . \)\),
                  SingleLetterItalics->False,
                  FontSlant->"Plain"]}]}
            }]}], NotebookDefault]], "BottomBox",
  CellTags->"Useage"],

Cell["", "Text",
  CellTags->"Useage"],

Cell["", "Text",
  CellTags->"Useage"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options", "Section",
  CellTags->"Options"],

Cell["Options for SeriesSolve", "Caption",
  CellTags->"Options"],

Cell["\<\
   Option               Default value                                         \
                        Explanation\
\>", "Caption",
  CellTags->"Options"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox["Order",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["2",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  StyleBox["maximum",
                    SingleLetterItalics->False], " ", 
                  StyleBox["series",
                    SingleLetterItalics->False], " ", 
                  StyleBox["expansion",
                    SingleLetterItalics->False], " ", 
                  StyleBox["order",
                    SingleLetterItalics->False], " "}],
                "StandardForm"],
              "Text"]},
          {
            StyleBox[
              FormBox["Root",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["1",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  RowBox[{
                    StyleBox["if",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["zeroth",
                      SingleLetterItalics->False], " ", 
                    StyleBox["order",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["equation",
                      SingleLetterItalics->False], 
                    RowBox[{
                      StyleBox["(",
                        SingleLetterItalics->False], 
                      RowBox[{
                        StyleBox["or",
                          SingleLetterItalics->False], " ", 
                        StyleBox["equations",
                          SingleLetterItalics->False]}], 
                      StyleBox[")",
                        SingleLetterItalics->False]}], " ", 
                    StyleBox["have",
                      SingleLetterItalics->False], " ", 
                    StyleBox["multiple",
                      SingleLetterItalics->False], " ", 
                    StyleBox["roots",
                      SingleLetterItalics->False]}], ",", " ", 
                  RowBox[{
                    StyleBox["this",
                      SingleLetterItalics->False], " ", 
                    StyleBox["is",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", "sequential", " ", 
                    StyleBox["number",
                      SingleLetterItalics->False], " ", 
                    StyleBox["of",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["root",
                      SingleLetterItalics->False]}], 
                  StyleBox[",",
                    SingleLetterItalics->False], " ", 
                  RowBox[{
                  "in", " ", "the", " ", "list", " ", "of", " ", "roots", 
                    " ", 
                    StyleBox["produced",
                      SingleLetterItalics->False], " ", 
                    StyleBox["by",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["Mathematica",
                      SingleLetterItalics->False], " ", "Solve", " ", 
                    StyleBox["function",
                      SingleLetterItalics->False]}], 
                  StyleBox[",",
                    SingleLetterItalics->False], " ", 
                  RowBox[{
                    StyleBox["used",
                      SingleLetterItalics->False], " ", 
                    StyleBox["to",
                      SingleLetterItalics->False], " ", 
                    StyleBox["generate",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["zeroth",
                      SingleLetterItalics->False], " ", 
                    StyleBox["term",
                      SingleLetterItalics->False], " ", 
                    StyleBox["in",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["Maclaurin",
                      SingleLetterItalics->False], " ", 
                    StyleBox["series",
                      SingleLetterItalics->False], " ", 
                    StyleBox["of",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["result",
                      SingleLetterItalics->False]}]}],
                "StandardForm"],
              "Text"]},
          {
            StyleBox[
              FormBox["SpeedSimp",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["True",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  StyleBox["parameter",
                    SingleLetterItalics->False], " ", 
                  StyleBox["for",
                    SingleLetterItalics->False], " ", 
                  StyleBox["selecting",
                    SingleLetterItalics->False], " ", 
                  StyleBox["between",
                    SingleLetterItalics->False], " ", 
                  StyleBox["maximum",
                    SingleLetterItalics->False], " ", 
                  StyleBox["calculation",
                    SingleLetterItalics->False], " ", 
                  StyleBox["speed",
                    SingleLetterItalics->False], " ", 
                  StyleBox["and",
                    SingleLetterItalics->False], " ", 
                  StyleBox["maximum",
                    SingleLetterItalics->False], " ", 
                  StyleBox["simplification",
                    SingleLetterItalics->False], " ", 
                  StyleBox["of",
                    SingleLetterItalics->False], " ", 
                  StyleBox["results",
                    SingleLetterItalics->False], 
                  StyleBox["...",
                    SingleLetterItalics->False], " ", "the", " ", "default", 
                  " ", "value", " ", "of", " ", "True", " ", "gives", " ", 
                  "maximum", " ", "speed", ",", 
                  StyleBox["setting",
                    SingleLetterItalics->False], " ", 
                  StyleBox["to",
                    SingleLetterItalics->False], " ", 
                  StyleBox["False",
                    SingleLetterItalics->False], " ", 
                  StyleBox["gives",
                    SingleLetterItalics->False], " ", 
                  StyleBox["maximum",
                    SingleLetterItalics->False], " ", 
                  StyleBox["simplification",
                    SingleLetterItalics->False]}],
                "StandardForm"],
              "Text"]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GridBoxOptions->{ColumnWidths->{0.2, 0.28, 0.52}},
  CellTags->"Options"],

Cell[BoxData[
    \(\(\n\n\)\)], "Input",
  CellTags->"Options"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section",
  CellTags->"Examples"],

Cell["This loads the package", "MathCaption",
  CellTags->"Examples"],

Cell[BoxData[
    \(<< SeriesSolve`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Examples"],

Cell["The first available example is the quadratic equation.", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[1]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(c0 + t\ x + x\^2 == 0\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Here, ",
  StyleBox["c0", "MR"],
  " is a constant and ",
  StyleBox["t", "MR"],
  " is the small parameter."
}], "MathCaption",
  CellTags->"Examples"],

Cell["\<\
This finds the Maclaurin series expansion of one of the roots (by default, \
the root is expressed to second order)\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[Eq[1], x, t]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
        InterpretationBox[
          RowBox[{
          \(\(-I\)\ \@c0\), "-", \(t\/2\), "+", \(\(I\ t\^2\)\/\(8\ \@c0\)\), 
            "+", 
            InterpretationBox[\(O[t]\^3\),
              SeriesData[ t, 0, {}, 0, 3, 1]]}],
          SeriesData[ t, 0, {
            Times[ 
              Complex[ 0, -1], 
              Power[ c0, 
                Rational[ 1, 2]]], 
            Rational[ -1, 2], 
            Times[ 
              Complex[ 0, 
                Rational[ 1, 8]], 
              Power[ c0, 
                Rational[ -1, 2]]]}, 0, 3, 1]]}], "}"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Higher-order terms in the series can be obtained by setting the ",
  StyleBox["Order", "MR"],
  " option. Here's the result to fifth order"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[Eq[1], x, t, Order -> 5]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
        InterpretationBox[
          RowBox[{
          \(\(-I\)\ \@c0\), "-", \(t\/2\), "+", \(\(I\ t\^2\)\/\(8\ \@c0\)\), 
            "+", \(\(I\ t\^4\)\/\(128\ c0\^\(3/2\)\)\), "+", 
            InterpretationBox[\(O[t]\^6\),
              SeriesData[ t, 0, {}, 0, 6, 1]]}],
          SeriesData[ t, 0, {
            Times[ 
              Complex[ 0, -1], 
              Power[ c0, 
                Rational[ 1, 2]]], 
            Rational[ -1, 2], 
            Times[ 
              Complex[ 0, 
                Rational[ 1, 8]], 
              Power[ c0, 
                Rational[ -1, 2]]], 0, 
            Times[ 
              Complex[ 0, 
                Rational[ 1, 128]], 
              Power[ c0, 
                Rational[ -3, 2]]]}, 0, 6, 1]]}], "}"}]], "Output",
  CellLabel->"Out[4]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "The second root is obtained by setting the ",
  StyleBox["Root", "MR"],
  " option to 2"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[Eq[1], x, t, Root -> 2]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
        InterpretationBox[
          RowBox[{
          \(I\ \@c0\), "-", \(t\/2\), "+", \(-\(\(I\ t\^2\)\/\(8\ \@c0\)\)\), 
            "+", 
            InterpretationBox[\(O[t]\^3\),
              SeriesData[ t, 0, {}, 0, 3, 1]]}],
          SeriesData[ t, 0, {
            Times[ 
              Complex[ 0, 1], 
              Power[ c0, 
                Rational[ 1, 2]]], 
            Rational[ -1, 2], 
            Times[ 
              Complex[ 0, 
                Rational[ -1, 8]], 
              Power[ c0, 
                Rational[ -1, 2]]]}, 0, 3, 1]]}], "}"}]], "Output",
  CellLabel->"Out[5]=",
  CellTags->"Examples"]
}, Open  ]],

Cell["The second example is a transcendental equation", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[2]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(\(-E\^\(a\ t\ x\)\) + x == 0\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Here,",
  StyleBox[" a", "MR"],
  " is a constant and ",
  StyleBox["t", "MR"],
  " is the small parameter."
}], "MathCaption",
  CellTags->"Examples"],

Cell["\<\
This gives the Maclaurin series solution of one root to fifth order\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[Eq[2], x, t, Order -> 5]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
        InterpretationBox[
          RowBox[{
          "1", "+", \(a\ t\), "+", \(\(3\ a\^2\ t\^2\)\/2\), "+", 
            \(\(8\ a\^3\ t\^3\)\/3\), "+", \(\(125\ a\^4\ t\^4\)\/24\), "+", 
            \(\(54\ a\^5\ t\^5\)\/5\), "+", 
            InterpretationBox[\(O[t]\^6\),
              SeriesData[ t, 0, {}, 0, 6, 1]]}],
          SeriesData[ t, 0, {1, a, 
            Times[ 
              Rational[ 3, 2], 
              Power[ a, 2]], 
            Times[ 
              Rational[ 8, 3], 
              Power[ a, 3]], 
            Times[ 
              Rational[ 125, 24], 
              Power[ a, 4]], 
            Times[ 
              Rational[ 54, 5], 
              Power[ a, 5]]}, 0, 6, 1]]}], "}"}]], "Output",
  CellLabel->"Out[7]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Although this transcendental equation generally has two roots, only one of \
these is expressible in a Maclaurin series, so",
  StyleBox[" SeriesSolve", "MR"],
  " finds only that one root."
}], "MathCaption",
  CellTags->"Examples"],

Cell["This example involves simultaneous equations", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[6]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(t\ y - x\ Sin[y] == 0\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[7]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(c0 + c1\ y + x\ y == 0\)], "Output",
  CellLabel->"Out[9]=",
  CellTags->"Examples"]
}, Open  ]],

Cell["\<\
This solves for the Maclaurin series expansion of one pair of simultaneous \
roots\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[{Eq[6], Eq[7]}, {x, y}, t]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"x", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            \(\(c0\ Csc[c0\/c1]\ t\)\/c1\), "+", 
              \(\((\(-\(\(c0\^2\ Csc[c0\/c1]\^2\)\/c1\^3\)\) + 
                    \(c0\^3\ Cot[c0\/c1]\ Csc[c0\/c1]\^2\)\/c1\^4)\)\ t\^2\), 
              "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 1, 3, 1]]}],
            SeriesData[ t, 0, {
              Times[ c0, 
                Power[ c1, -1], 
                Csc[ 
                  Times[ c0, 
                    Power[ c1, -1]]]], 
              Plus[ 
                Times[ -1, 
                  Power[ c0, 2], 
                  Power[ c1, -3], 
                  Power[ 
                    Csc[ 
                      Times[ c0, 
                        Power[ c1, -1]]], 2]], 
                Times[ 
                  Power[ c0, 3], 
                  Power[ c1, -4], 
                  Cot[ 
                    Times[ c0, 
                      Power[ c1, -1]]], 
                  Power[ 
                    Csc[ 
                      Times[ c0, 
                        Power[ c1, -1]]], 2]]]}, 1, 3, 1]]}], ",", 
        RowBox[{"y", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            \(-\(c0\/c1\)\), "+", \(\(c0\^2\ Csc[c0\/c1]\ t\)\/c1\^3\), "+", 
              \(\((\(-\(\(2\ c0\^3\ Csc[c0\/c1]\^2\)\/c1\^5\)\) + 
                    \(c0\^4\ Cot[c0\/c1]\ Csc[c0\/c1]\^2\)\/c1\^6)\)\ t\^2\), 
              "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 0, 3, 1]]}],
            SeriesData[ t, 0, {
              Times[ -1, c0, 
                Power[ c1, -1]], 
              Times[ 
                Power[ c0, 2], 
                Power[ c1, -3], 
                Csc[ 
                  Times[ c0, 
                    Power[ c1, -1]]]], 
              Plus[ 
                Times[ -2, 
                  Power[ c0, 3], 
                  Power[ c1, -5], 
                  Power[ 
                    Csc[ 
                      Times[ c0, 
                        Power[ c1, -1]]], 2]], 
                Times[ 
                  Power[ c0, 4], 
                  Power[ c1, -6], 
                  Cot[ 
                    Times[ c0, 
                      Power[ c1, -1]]], 
                  Power[ 
                    Csc[ 
                      Times[ c0, 
                        Power[ c1, -1]]], 2]]]}, 0, 3, 1]]}]}], "}"}]], 
  "Output",
  CellLabel->"Out[10]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "The results can be obtained in simpler form by setting the ",
  StyleBox["SpeedSimp", "MR"],
  StyleBox[" ", "MR"],
  "option to ",
  StyleBox["False", "MR"]
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[{Eq[6], Eq[7]}, {x, y}, t, SpeedSimp -> False]\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"x", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            \(\(c0\ Csc[c0\/c1]\ t\)\/c1\), "+", 
              \(\(c0\^2\ Csc[c0\/c1]\^3\ 
                    \((c0\ Cos[c0\/c1] - c1\ Sin[c0\/c1])\)\ t\^2\)\/c1\^4\), 
              "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 1, 3, 1]]}],
            SeriesData[ t, 0, {
              Times[ c0, 
                Power[ c1, -1], 
                Csc[ 
                  Times[ c0, 
                    Power[ c1, -1]]]], 
              Times[ 
                Power[ c0, 2], 
                Power[ c1, -4], 
                Power[ 
                  Csc[ 
                    Times[ c0, 
                      Power[ c1, -1]]], 3], 
                Plus[ 
                  Times[ c0, 
                    Cos[ 
                      Times[ c0, 
                        Power[ c1, -1]]]], 
                  Times[ -1, c1, 
                    Sin[ 
                      Times[ c0, 
                        Power[ c1, -1]]]]]]}, 1, 3, 1]]}], ",", 
        RowBox[{"y", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            \(-\(c0\/c1\)\), "+", \(\(c0\^2\ Csc[c0\/c1]\ t\)\/c1\^3\), "+", 
              \(\(c0\^3\ Csc[c0\/c1]\^3\ 
                    \((c0\ Cos[c0\/c1] - 2\ c1\ Sin[c0\/c1])\)\ t\^2\)\/c1\^6
                    \), "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 0, 3, 1]]}],
            SeriesData[ t, 0, {
              Times[ -1, c0, 
                Power[ c1, -1]], 
              Times[ 
                Power[ c0, 2], 
                Power[ c1, -3], 
                Csc[ 
                  Times[ c0, 
                    Power[ c1, -1]]]], 
              Times[ 
                Power[ c0, 3], 
                Power[ c1, -6], 
                Power[ 
                  Csc[ 
                    Times[ c0, 
                      Power[ c1, -1]]], 3], 
                Plus[ 
                  Times[ c0, 
                    Cos[ 
                      Times[ c0, 
                        Power[ c1, -1]]]], 
                  Times[ -2, c1, 
                    Sin[ 
                      Times[ c0, 
                        Power[ c1, -1]]]]]]}, 0, 3, 1]]}]}], "}"}]], "Output",\

  CellLabel->"Out[11]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "To find out how many Maclaurin series roots are available, apply ",
  StyleBox["SeriesSolve ", "MR"],
  "using a large value of the ",
  StyleBox["Root ", "MR"],
  "option"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[{Eq[6], Eq[7]}, {x, y}, t, Root -> 100]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(SeriesSolve::"insufficientroots" \( : \ \) 
      "chosen multiple root exceeds number of available roots = \!\(2\)"\)], 
  "Message",
  CellTags->"Examples"],

Cell[BoxData[
    \(Applications`SeriesSolve`Private`maclaurin$27\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Now we know there are two available Maclaurin roots, and can get the \
second root by setting the ",
  StyleBox["Root", "MR"],
  " option to 2"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[{Eq[6], Eq[7]}, {x, y}, t, Root -> 2]\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"x", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            \(-\(\(c0 + c1\ \[Pi]\)\/\[Pi]\)\), "+", 
              \(\(c0\ t\)\/\(c0 + c1\ \[Pi]\)\), "+", 
              \(\(c0\^2\ \[Pi]\ t\^2\)\/\((c0 + c1\ \[Pi])\)\^3\), "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 0, 3, 1]]}],
            SeriesData[ t, 0, {
              Times[ -1, 
                Power[ Pi, -1], 
                Plus[ c0, 
                  Times[ c1, Pi]]], 
              Times[ c0, 
                Power[ 
                  Plus[ c0, 
                    Times[ c1, Pi]], -1]], 
              Times[ 
                Power[ c0, 2], Pi, 
                Power[ 
                  Plus[ c0, 
                    Times[ c1, Pi]], -3]]}, 0, 3, 1]]}], ",", 
        RowBox[{"y", "\[Rule]", 
          InterpretationBox[
            RowBox[{
            "\[Pi]", "+", \(\(\[Pi]\^2\ t\)\/\(c0 + c1\ \[Pi]\)\), "+", 
              \(\((\(2\ c0\ \[Pi]\^3\)\/\((c0 + c1\ \[Pi])\)\^3 + 
                    \(c1\ \[Pi]\^4\)\/\((c0 + c1\ \[Pi])\)\^3)\)\ t\^2\), 
              "+", 
              InterpretationBox[\(O[t]\^3\),
                SeriesData[ t, 0, {}, 0, 3, 1]]}],
            SeriesData[ t, 0, {Pi, 
              Times[ 
                Power[ Pi, 2], 
                Power[ 
                  Plus[ c0, 
                    Times[ c1, Pi]], -1]], 
              Plus[ 
                Times[ 2, c0, 
                  Power[ Pi, 3], 
                  Power[ 
                    Plus[ c0, 
                      Times[ c1, Pi]], -3]], 
                Times[ c1, 
                  Power[ Pi, 4], 
                  Power[ 
                    Plus[ c0, 
                      Times[ c1, Pi]], -3]]]}, 0, 3, 1]]}]}], "}"}]], "Output",\

  CellLabel->"Out[13]=",
  CellTags->"Examples"]
}, Open  ]],

Cell["\<\
This example is a classic \"unsolved\" problem, the sixth degree polynomial\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[24]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(c0 + c1\ t\^6\ x + c2\ t\^6\ x\^2 + c3\ t\^6\ x\^3 + c4\ t\^6\ x\^4 + 
        c5\ t\^6\ x\^5 + x\^6 == 0\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Notice that the \"small parameter\" ",
  StyleBox["t ", "MR"],
  "is expressed to the sixth power here. If it were expressed to the first \
power instead, the equation would not have any Maclaurin series roots."
}], "MathCaption",
  CellTags->"Examples"],

Cell[TextData[{
  "For this equation, the ordinary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Solve", "MR"],
  " function cannot get an analytical solution, but instead gives a symbolic \
representation of the roots"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[Eq[24], x]\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \({{x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 1]}, {
        x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 2]}, {
        x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 3]}, {
        x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 4]}, {
        x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 5]}, {
        x \[Rule] 
          Root[c0 + c1\ t\^6\ #1 + c2\ t\^6\ #1\^2 + c3\ t\^6\ #1\^3 + 
                c4\ t\^6\ #1\^4 + c5\ t\^6\ #1\^5 + #1\^6&, 6]}}\)], "Output",\

  CellLabel->"Out[15]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "But ",
  StyleBox["SeriesSolve ", "MR"],
  "can give the Maclaurin series representation of any of the six roots. This \
gives one of them"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[Eq[24], x, t, Order -> 6]\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
        InterpretationBox[
          RowBox[{
          \(\(-I\)\ c0\^\(1/6\)\), "+", 
            \(\((\(-\(c1\/\(6\ c0\^\(2/3\)\)\)\) + \(I\ c2\)\/\(6\ \@c0\) + 
                  c3\/\(6\ c0\^\(1/3\)\) - \(I\ c4\)\/\(6\ c0\^\(1/6\)\) - 
                  c5\/6)\)\ t\^6\), "+", 
            InterpretationBox[\(O[t]\^7\),
              SeriesData[ t, 0, {}, 0, 7, 1]]}],
          SeriesData[ t, 0, {
            Times[ 
              Complex[ 0, -1], 
              Power[ c0, 
                Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
            Plus[ 
              Times[ 
                Rational[ -1, 6], 
                Power[ c0, 
                  Rational[ -2, 3]], c1], 
              Times[ 
                Complex[ 0, 
                  Rational[ 1, 6]], 
                Power[ c0, 
                  Rational[ -1, 2]], c2], 
              Times[ 
                Rational[ 1, 6], 
                Power[ c0, 
                  Rational[ -1, 3]], c3], 
              Times[ 
                Complex[ 0, 
                  Rational[ -1, 6]], 
                Power[ c0, 
                  Rational[ -1, 6]], c4], 
              Times[ 
                Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}]], "Output",
  CellLabel->"Out[16]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "Notice that the ",
  StyleBox["Order", "MR"],
  " option had to be set to 6 to get the first nontrivial term beyond the \
constant term."
}], "MathCaption",
  CellTags->"Examples"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Table", "MR"],
  " function can be used to generate the Maclaurin series expansions of all \
six of the roots"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SeriesSolve[Eq[24], x, t, Order -> 6, Root -> n], {n, 1, 6}]\)], 
  "Input",
  CellLabel->"In[17]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(\(-I\)\ c0\^\(1/6\)\), "+", 
                \(\((\(-\(c1\/\(6\ c0\^\(2/3\)\)\)\) + 
                      \(I\ c2\)\/\(6\ \@c0\) + c3\/\(6\ c0\^\(1/3\)\) - 
                      \(I\ c4\)\/\(6\ c0\^\(1/6\)\) - c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ 
                  Complex[ 0, -1], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ -1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(I\ c0\^\(1/6\)\), "+", 
                \(\((\(-\(c1\/\(6\ c0\^\(2/3\)\)\)\) - 
                      \(I\ c2\)\/\(6\ \@c0\) + c3\/\(6\ c0\^\(1/3\)\) + 
                      \(I\ c4\)\/\(6\ c0\^\(1/6\)\) - c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ 
                  Complex[ 0, 1], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ -1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(-\(\((\(-1\))\)\^\(1/6\)\ c0\^\(1/6\)\)\), "+", 
                \(\((\(\((\(-1\))\)\^\(1/3\)\ c1\)\/\(6\ c0\^\(2/3\)\) - 
                      \(I\ c2\)\/\(6\ \@c0\) + 
                      \(\((\(-1\))\)\^\(2/3\)\ c3\)\/\(6\ c0\^\(1/3\)\) - 
                      \(\((\(-1\))\)\^\(5/6\)\ c4\)\/\(6\ c0\^\(1/6\)\) - 
                      c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ -1, 
                  Power[ -1, 
                    Rational[ 1, 6]], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 1, 3]], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ -1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 2, 3]], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 5, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(\((\(-1\))\)\^\(1/6\)\ c0\^\(1/6\)\), "+", 
                \(\((\(\((\(-1\))\)\^\(1/3\)\ c1\)\/\(6\ c0\^\(2/3\)\) + 
                      \(I\ c2\)\/\(6\ \@c0\) + 
                      \(\((\(-1\))\)\^\(2/3\)\ c3\)\/\(6\ c0\^\(1/3\)\) + 
                      \(\((\(-1\))\)\^\(5/6\)\ c4\)\/\(6\ c0\^\(1/6\)\) - 
                      c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ 
                  Power[ -1, 
                    Rational[ 1, 6]], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 1, 3]], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 2, 3]], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 5, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(-\(\((\(-1\))\)\^\(5/6\)\ c0\^\(1/6\)\)\), "+", 
                \(\((\(-
                        \(\(\((\(-1\))\)\^\(2/3\)\ c1\)\/\(6\ 
                              c0\^\(2/3\)\)\)\) - \(I\ c2\)\/\(6\ \@c0\) - 
                      \(\((\(-1\))\)\^\(1/3\)\ c3\)\/\(6\ c0\^\(1/3\)\) - 
                      \(\((\(-1\))\)\^\(1/6\)\ c4\)\/\(6\ c0\^\(1/6\)\) - 
                      c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ -1, 
                  Power[ -1, 
                    Rational[ 5, 6]], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 2, 3]], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ -1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 1, 3]], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
            InterpretationBox[
              RowBox[{
              \(\((\(-1\))\)\^\(5/6\)\ c0\^\(1/6\)\), "+", 
                \(\((\(-
                        \(\(\((\(-1\))\)\^\(2/3\)\ c1\)\/\(6\ 
                              c0\^\(2/3\)\)\)\) + \(I\ c2\)\/\(6\ \@c0\) - 
                      \(\((\(-1\))\)\^\(1/3\)\ c3\)\/\(6\ c0\^\(1/3\)\) + 
                      \(\((\(-1\))\)\^\(1/6\)\ c4\)\/\(6\ c0\^\(1/6\)\) - 
                      c5\/6)\)\ t\^6\), "+", 
                InterpretationBox[\(O[t]\^7\),
                  SeriesData[ t, 0, {}, 0, 7, 1]]}],
              SeriesData[ t, 0, {
                Times[ 
                  Power[ -1, 
                    Rational[ 5, 6]], 
                  Power[ c0, 
                    Rational[ 1, 6]]], 0, 0, 0, 0, 0, 
                Plus[ 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 2, 3]], 
                    Power[ c0, 
                      Rational[ -2, 3]], c1], 
                  Times[ 
                    Complex[ 0, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 2]], c2], 
                  Times[ 
                    Rational[ -1, 6], 
                    Power[ -1, 
                      Rational[ 1, 3]], 
                    Power[ c0, 
                      Rational[ -1, 3]], c3], 
                  Times[ 
                    Rational[ 1, 6], 
                    Power[ -1, 
                      Rational[ 1, 6]], 
                    Power[ c0, 
                      Rational[ -1, 6]], c4], 
                  Times[ 
                    Rational[ -1, 6], c5]]}, 0, 7, 1]]}], "}"}]}], "}"}]], 
  "Output",
  CellLabel->"Out[17]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "This example shows how ",
  StyleBox["SeriesSolve ", "MR"],
  "can handle very intricate simultaneous equations"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[13]\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(x\^2 + t\^2\ x\ y + z\^2 + c0\ E\^\(x\ y\)\ t\^2\ Sin[w] == 0\)], 
  "Output",
  CellLabel->"Out[18]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[14]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(x + y + z\^2 == 0\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[15]\)], "Input",
  CellLabel->"In[20]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(x - y - t\ z\ BesselJ[0, z] == 0\)], "Output",
  CellLabel->"Out[20]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq[16]\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(x - Cos[w] - t\ Tanh[y] == 0\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->"Examples"]
}, Open  ]],

Cell[TextData[{
  "This example contains the four variables ",
  StyleBox["{w,x,y,z}", "MR"],
  " and one constant ",
  StyleBox["c0", "MR"],
  "."
}], "MathCaption",
  CellTags->"Examples"],

Cell[TextData[{
  "We proceed by first finding out how many Maclaurin roots are available by \
setting the ",
  StyleBox["Root", "MR"],
  " option to a high value"
}], "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesSolve[{Eq[13], Eq[14], Eq[15], Eq[16]}, {w, x, y, z}, t, 
      Root -> 100]\)], "Input",
  CellLabel->"In[22]:=",
  CellTags->"Examples"],

Cell[BoxData[
    \(SeriesSolve::"insufficientroots" \( : \ \) 
      "chosen multiple root exceeds number of available roots = \!\(6\)"\)], 
  "Message",
  CellTags->"Examples"],

Cell[BoxData[
    \(Applications`SeriesSolve`Private`maclaurin$54\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->"Examples"]
}, Open  ]],

Cell["\<\
We then find the first-order Maclaurin series for all of the six available \
roots\
\>", "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      SeriesSolve[{Eq[13], Eq[14], Eq[15], Eq[16]}, {w, x, y, z}, t, 
        Order -> 1, Root -> n], {n, 1, 6}]\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->"Examples"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(-\(\[Pi]\/2\)\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ 
                    Rational[ -1, 2], Pi]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[\(O[t]\^2\),
                SeriesData[ t, 0, {}, 2, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[\(O[t]\^2\),
                SeriesData[ t, 0, {}, 2, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(-\(\@c0\ t\)\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 1, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ -1, 
                    Power[ c0, 
                      Rational[ 1, 2]]]}, 1, 2, 1]]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(\[Pi]\/2\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ 
                    Rational[ 1, 2], Pi]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[\(O[t]\^2\),
                SeriesData[ t, 0, {}, 2, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[\(O[t]\^2\),
                SeriesData[ t, 0, {}, 2, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(I\ \@c0\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 1, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ 
                    Complex[ 0, 1], 
                    Power[ c0, 
                      Rational[ 1, 2]]]}, 1, 2, 1]]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(-ArcCos[2]\), "+", 
                  \(\((BesselJ[0, \(-2\)\ I]\/\@3 + \(I\ Tanh[2]\)\/\@3)\)\ t
                    \), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ -1, 
                    ArcCos[ 2]], 
                  Plus[ 
                    Times[ 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      BesselJ[ 0, 
                        Complex[ 0, -2]]], 
                    Times[ 
                      Complex[ 0, 1], 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      Tanh[ 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(I\ BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, 1], 
                    BesselJ[ 0, 
                      Complex[ 0, -2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(3\ I\ BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, 3], 
                    BesselJ[ 0, 
                      Complex[ 0, -2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(-\(2\ I\)\), "+", \(BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Complex[ 0, -2], 
                  BesselJ[ 0, 
                    Complex[ 0, -2]]}, 0, 2, 1]]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(ArcCos[2]\), "+", 
                  \(\((\(-\(BesselJ[0, \(-2\)\ I]\/\@3\)\) - 
                        \(I\ Tanh[2]\)\/\@3)\)\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  ArcCos[ 2], 
                  Plus[ 
                    Times[ -1, 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      BesselJ[ 0, 
                        Complex[ 0, -2]]], 
                    Times[ 
                      Complex[ 0, -1], 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      Tanh[ 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(I\ BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, 1], 
                    BesselJ[ 0, 
                      Complex[ 0, -2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(3\ I\ BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, 3], 
                    BesselJ[ 0, 
                      Complex[ 0, -2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(-\(2\ I\)\), "+", \(BesselJ[0, \(-2\)\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Complex[ 0, -2], 
                  BesselJ[ 0, 
                    Complex[ 0, -2]]}, 0, 2, 1]]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(-ArcCos[2]\), "+", 
                  \(\((\(-\(BesselJ[0, 2\ I]\/\@3\)\) + \(I\ Tanh[2]\)\/\@3)
                      \)\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Times[ -1, 
                    ArcCos[ 2]], 
                  Plus[ 
                    Times[ -1, 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      BesselJ[ 0, 
                        Complex[ 0, 2]]], 
                    Times[ 
                      Complex[ 0, 1], 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      Tanh[ 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(\(-I\)\ BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, -1], 
                    BesselJ[ 0, 
                      Complex[ 0, 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(\(-3\)\ I\ BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, -3], 
                    BesselJ[ 0, 
                      Complex[ 0, 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(2\ I\), "+", \(BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Complex[ 0, 2], 
                  BesselJ[ 0, 
                    Complex[ 0, 2]]}, 0, 2, 1]]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"w", "\[Rule]", 
              InterpretationBox[
                RowBox[{
                \(ArcCos[2]\), "+", 
                  \(\((BesselJ[0, 2\ I]\/\@3 - \(I\ Tanh[2]\)\/\@3)\)\ t\), 
                  "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  ArcCos[ 2], 
                  Plus[ 
                    Times[ 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      BesselJ[ 0, 
                        Complex[ 0, 2]]], 
                    Times[ 
                      Complex[ 0, -1], 
                      Power[ 3, 
                        Rational[ -1, 2]], 
                      Tanh[ 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"x", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(\(-I\)\ BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, -1], 
                    BesselJ[ 0, 
                      Complex[ 0, 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"y", "\[Rule]", 
              InterpretationBox[
                RowBox[{"2", "+", \(\(-3\)\ I\ BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {2, 
                  Times[ 
                    Complex[ 0, -3], 
                    BesselJ[ 0, 
                      Complex[ 0, 2]]]}, 0, 2, 1]]}], ",", 
            RowBox[{"z", "\[Rule]", 
              InterpretationBox[
                RowBox[{\(2\ I\), "+", \(BesselJ[0, 2\ I]\ t\), "+", 
                  InterpretationBox[\(O[t]\^2\),
                    SeriesData[ t, 0, {}, 0, 2, 1]]}],
                SeriesData[ t, 0, {
                  Complex[ 0, 2], 
                  BesselJ[ 0, 
                    Complex[ 0, 2]]}, 0, 2, 1]]}]}], "}"}]}], "}"}]], "Output",\

  CellLabel->"Out[23]=",
  CellTags->"Examples"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 640}, {0, 392}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"AllBrackets",
WindowSize->{493, 155},
WindowMargins->{{26, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Manual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[1796, 53, 82, 2, 72, "Section",
      CellTags->"Introduction"],
    Cell[1881, 57, 2102, 45, 514, "Text",
      CellTags->"Introduction"]},
  "Useage"->{
    Cell[4020, 107, 47, 1, 72, "Section",
      CellTags->"Useage"],
    Cell[4070, 110, 63, 1, 16, "Caption",
      CellTags->"Useage"],
    Cell[4136, 113, 717, 24, 39, "TopSpanBox",
      CellTags->"Useage"],
    Cell[4856, 139, 5956, 143, 90, "BottomBox",
      CellTags->"Useage"],
    Cell[10815, 284, 38, 1, 33, "Text",
      CellTags->"Useage"],
    Cell[10856, 287, 38, 1, 33, "Text",
      CellTags->"Useage"]},
  "Options"->{
    Cell[10931, 293, 49, 1, 72, "Section",
      CellTags->"Options"],
    Cell[10983, 296, 65, 1, 16, "Caption",
      CellTags->"Options"],
    Cell[11051, 299, 165, 4, 16, "Caption",
      CellTags->"Options"],
    Cell[11219, 305, 7574, 182, 362, "DefinitionBox3Col",
      CellTags->"Options"],
    Cell[18796, 489, 64, 2, 70, "Input",
      CellTags->"Options"]},
  "Examples"->{
    Cell[18897, 496, 51, 1, 72, "Section",
      CellTags->"Examples"],
    Cell[18951, 499, 69, 1, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[19023, 502, 96, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[19122, 507, 101, 1, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[19248, 512, 86, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[19337, 517, 103, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[19455, 523, 171, 7, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[19629, 532, 170, 4, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[19824, 540, 105, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[19932, 545, 696, 21, 49, "Output",
      CellTags->"Examples"],
    Cell[20643, 569, 201, 5, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[20869, 578, 117, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[20989, 583, 890, 26, 49, "Output",
      CellTags->"Examples"],
    Cell[21894, 612, 150, 5, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[22069, 621, 116, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[22188, 626, 696, 21, 49, "Output",
      CellTags->"Examples"],
    Cell[22899, 650, 94, 1, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[23018, 655, 86, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[23107, 660, 110, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[23232, 666, 170, 7, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[23405, 675, 122, 3, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[23552, 682, 117, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[23672, 687, 837, 24, 44, "Output",
      CellTags->"Examples"],
    Cell[24524, 714, 252, 6, 65, "MathCaption",
      CellTags->"Examples"],
    Cell[24779, 722, 91, 1, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[24895, 727, 86, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[24984, 732, 103, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[25124, 740, 86, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[25213, 745, 104, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[25332, 751, 137, 4, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[25494, 759, 120, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[25617, 764, 2577, 74, 201, "Output",
      CellTags->"Examples"],
    Cell[28209, 841, 219, 7, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[28453, 852, 140, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[28596, 857, 2402, 70, 183, "Output",
      CellTags->"Examples"],
    Cell[31013, 930, 234, 7, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[31272, 941, 133, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[31408, 946, 178, 4, 46, "Message",
      CellTags->"Examples"],
    Cell[31589, 952, 128, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[31732, 958, 205, 6, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[31962, 968, 131, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[32096, 973, 1899, 53, 86, "Output",
      CellTags->"Examples"],
    Cell[34010, 1029, 130, 3, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[34165, 1036, 88, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[34256, 1041, 188, 4, 29, "Output",
      CellTags->"Examples"],
    Cell[34459, 1048, 273, 6, 65, "MathCaption",
      CellTags->"Examples"],
    Cell[34735, 1056, 290, 9, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[35050, 1069, 98, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[35151, 1074, 1024, 21, 257, "Output",
      CellTags->"Examples"],
    Cell[36190, 1098, 201, 6, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[36416, 1108, 119, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[36538, 1113, 1331, 38, 76, "Output",
      CellTags->"Examples"],
    Cell[37884, 1154, 199, 6, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[38086, 1162, 250, 9, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[38361, 1175, 151, 4, 50, "Input",
      CellTags->"Examples"],
    Cell[38515, 1181, 10024, 255, 503, "Output",
      CellTags->"Examples"],
    Cell[48554, 1439, 174, 5, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[48753, 1448, 88, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[48844, 1453, 147, 4, 29, "Output",
      CellTags->"Examples"],
    Cell[49028, 1462, 88, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[49119, 1467, 100, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[49256, 1475, 88, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[49347, 1480, 115, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[49499, 1488, 88, 3, 30, "Input",
      CellTags->"Examples"],
    Cell[49590, 1493, 111, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[49716, 1499, 190, 7, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[49909, 1508, 206, 6, 48, "MathCaption",
      CellTags->"Examples"],
    Cell[50140, 1518, 164, 4, 50, "Input",
      CellTags->"Examples"],
    Cell[50307, 1524, 178, 4, 46, "Message",
      CellTags->"Examples"],
    Cell[50488, 1530, 128, 3, 29, "Output",
      CellTags->"Examples"],
    Cell[50631, 1536, 137, 4, 31, "MathCaption",
      CellTags->"Examples"],
    Cell[50793, 1544, 201, 5, 70, "Input",
      CellTags->"Examples"],
    Cell[50997, 1551, 11036, 268, 492, "Output",
      CellTags->"Examples"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 62825, 1844},
  {"Useage", 62989, 1849},
  {"Options", 63426, 1862},
  {"Examples", 63812, 1873}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 62, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[1796, 53, 82, 2, 72, "Section",
  CellTags->"Introduction"],
Cell[1881, 57, 2102, 45, 514, "Text",
  CellTags->"Introduction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4020, 107, 47, 1, 72, "Section",
  CellTags->"Useage"],
Cell[4070, 110, 63, 1, 16, "Caption",
  CellTags->"Useage"],
Cell[4136, 113, 717, 24, 39, "TopSpanBox",
  CellTags->"Useage"],
Cell[4856, 139, 5956, 143, 90, "BottomBox",
  CellTags->"Useage"],
Cell[10815, 284, 38, 1, 33, "Text",
  CellTags->"Useage"],
Cell[10856, 287, 38, 1, 33, "Text",
  CellTags->"Useage"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10931, 293, 49, 1, 72, "Section",
  CellTags->"Options"],
Cell[10983, 296, 65, 1, 16, "Caption",
  CellTags->"Options"],
Cell[11051, 299, 165, 4, 16, "Caption",
  CellTags->"Options"],
Cell[11219, 305, 7574, 182, 362, "DefinitionBox3Col",
  CellTags->"Options"],
Cell[18796, 489, 64, 2, 70, "Input",
  CellTags->"Options"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18897, 496, 51, 1, 72, "Section",
  CellTags->"Examples"],
Cell[18951, 499, 69, 1, 31, "MathCaption",
  CellTags->"Examples"],
Cell[19023, 502, 96, 3, 30, "Input",
  CellTags->"Examples"],
Cell[19122, 507, 101, 1, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[19248, 512, 86, 3, 30, "Input",
  CellTags->"Examples"],
Cell[19337, 517, 103, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[19455, 523, 171, 7, 31, "MathCaption",
  CellTags->"Examples"],
Cell[19629, 532, 170, 4, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[19824, 540, 105, 3, 30, "Input",
  CellTags->"Examples"],
Cell[19932, 545, 696, 21, 49, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[20643, 569, 201, 5, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[20869, 578, 117, 3, 30, "Input",
  CellTags->"Examples"],
Cell[20989, 583, 890, 26, 49, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[21894, 612, 150, 5, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[22069, 621, 116, 3, 30, "Input",
  CellTags->"Examples"],
Cell[22188, 626, 696, 21, 49, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[22899, 650, 94, 1, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[23018, 655, 86, 3, 30, "Input",
  CellTags->"Examples"],
Cell[23107, 660, 110, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[23232, 666, 170, 7, 31, "MathCaption",
  CellTags->"Examples"],
Cell[23405, 675, 122, 3, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[23552, 682, 117, 3, 30, "Input",
  CellTags->"Examples"],
Cell[23672, 687, 837, 24, 44, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[24524, 714, 252, 6, 65, "MathCaption",
  CellTags->"Examples"],
Cell[24779, 722, 91, 1, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[24895, 727, 86, 3, 30, "Input",
  CellTags->"Examples"],
Cell[24984, 732, 103, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25124, 740, 86, 3, 30, "Input",
  CellTags->"Examples"],
Cell[25213, 745, 104, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[25332, 751, 137, 4, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[25494, 759, 120, 3, 30, "Input",
  CellTags->"Examples"],
Cell[25617, 764, 2577, 74, 201, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[28209, 841, 219, 7, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[28453, 852, 140, 3, 30, "Input",
  CellTags->"Examples"],
Cell[28596, 857, 2402, 70, 183, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[31013, 930, 234, 7, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[31272, 941, 133, 3, 30, "Input",
  CellTags->"Examples"],
Cell[31408, 946, 178, 4, 46, "Message",
  CellTags->"Examples"],
Cell[31589, 952, 128, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[31732, 958, 205, 6, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[31962, 968, 131, 3, 30, "Input",
  CellTags->"Examples"],
Cell[32096, 973, 1899, 53, 86, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[34010, 1029, 130, 3, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[34165, 1036, 88, 3, 30, "Input",
  CellTags->"Examples"],
Cell[34256, 1041, 188, 4, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[34459, 1048, 273, 6, 65, "MathCaption",
  CellTags->"Examples"],
Cell[34735, 1056, 290, 9, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[35050, 1069, 98, 3, 30, "Input",
  CellTags->"Examples"],
Cell[35151, 1074, 1024, 21, 257, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[36190, 1098, 201, 6, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[36416, 1108, 119, 3, 30, "Input",
  CellTags->"Examples"],
Cell[36538, 1113, 1331, 38, 76, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[37884, 1154, 199, 6, 48, "MathCaption",
  CellTags->"Examples"],
Cell[38086, 1162, 250, 9, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[38361, 1175, 151, 4, 50, "Input",
  CellTags->"Examples"],
Cell[38515, 1181, 10024, 255, 503, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[48554, 1439, 174, 5, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[48753, 1448, 88, 3, 30, "Input",
  CellTags->"Examples"],
Cell[48844, 1453, 147, 4, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49028, 1462, 88, 3, 30, "Input",
  CellTags->"Examples"],
Cell[49119, 1467, 100, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49256, 1475, 88, 3, 30, "Input",
  CellTags->"Examples"],
Cell[49347, 1480, 115, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49499, 1488, 88, 3, 30, "Input",
  CellTags->"Examples"],
Cell[49590, 1493, 111, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[49716, 1499, 190, 7, 31, "MathCaption",
  CellTags->"Examples"],
Cell[49909, 1508, 206, 6, 48, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[50140, 1518, 164, 4, 50, "Input",
  CellTags->"Examples"],
Cell[50307, 1524, 178, 4, 46, "Message",
  CellTags->"Examples"],
Cell[50488, 1530, 128, 3, 29, "Output",
  CellTags->"Examples"]
}, Open  ]],
Cell[50631, 1536, 137, 4, 31, "MathCaption",
  CellTags->"Examples"],

Cell[CellGroupData[{
Cell[50793, 1544, 201, 5, 70, "Input",
  CellTags->"Examples"],
Cell[50997, 1551, 11036, 268, 492, "Output",
  CellTags->"Examples"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

